# Demo

<iframe src="./_static/lab/index.html?path=demo.ipynb&"></iframe>

<style>
    h1 { display: none; }
    iframe {
        flex: 1;
    }
    .bd-container, .bd-container__inner, .bd-content, .bd-article-container, .bd-article, #demo {
        width: 100% !important;
        max-width: unset !important;
        margin: 0 !important;
        padding: 0 !important;
        justify-content: stretch;
        flex: 1;
        display: flex;
        flex-direction: column;
    }
    .bd-header-article, .bd-sidebar-secondary, .bd-footer-article, .bd-footer, .admonition {
        display: none;
    }
</style>
